tlslite.integration.AsyncStateMachine

Package tlslite :: Package integration :: Module AsyncStateMachine |
[show private | hide private]
[frames | no frames]

## Module tlslite.integration.AsyncStateMachine

A state machine for using TLS Lite with asynchronous I/O.

Classes
`AsyncStateMachine` | This is an abstract class that's used to integrate TLS Lite with asyncore and Twisted.

Generated by Epydoc 2.0 on Mon Feb 21 21:56:55 2005 | http://epydoc.sf.net